@@ -10,5 +10,13 @@ class OwletAuthenticationError(OwletError):
     """When login details are incorrect"""
 
 
+class OwletPasswordError(OwletError):
+    """When password is incorrect"""
+
+
+class OwletEmailError(OwletError):
+    """When email is incorrect"""
+
+
 class OwletDevicesError(OwletError):
     """when no devices are found"""
